@@ -15,27 +15,25 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef THUMBNAILPICKER_H_
-#define THUMBNAILPICKER_H_
-
-#include <QPixmap>
-#include <QDialog>
-
-#include <KJob>
-#include <KLocalizedString>
-#include <KIO/Job>
+#pragma once
 
 #include "ui_thumbnailpicker.h"
 
-class QPixmap;
+#include <KIO/Job>
+
+#include <QDialog>
+#include <QPixmap>
+
 class QRect;
+class KJob;
 class DetailDialog;
 class SkyObject;
 
-class ThumbnailPickerUI : public QFrame, public Ui::ThumbnailPicker {
+class ThumbnailPickerUI : public QFrame, public Ui::ThumbnailPicker
+{
     Q_OBJECT
-public:
-    explicit ThumbnailPickerUI( QWidget *p );
+  public:
+    explicit ThumbnailPickerUI(QWidget *p);
 };
 
 /** @short Dialog for modifying an object's thumbnail image
@@ -44,40 +42,38 @@ public:
 class ThumbnailPicker : public QDialog
 {
     Q_OBJECT
-public:
-    ThumbnailPicker( SkyObject *o, const QPixmap &current, QWidget *parent=0, double w = 200, double h= 200, QString cap = i18n ( "Choose Thumbnail Image" ) );
+  public:
+    ThumbnailPicker(SkyObject *o, const QPixmap &current, QWidget *parent = 0, double w = 200, double h = 200,
+                    QString cap = i18n("Choose Thumbnail Image"));
     ~ThumbnailPicker();
 
-    QPixmap* image() { return Image; }
-    QPixmap* currentListImage() { return PixList.at( SelectedImageIndex ); }
+    QPixmap *image() { return Image; }
+    QPixmap *currentListImage() { return PixList.at(SelectedImageIndex); }
     bool imageFound() const { return bImageFound; }
-    QRect* imageRect() const { return ImageRect; }
+    QRect *imageRect() const { return ImageRect; }
 
-private slots:
+  private slots:
     void slotEditImage();
     void slotUnsetImage();
-    void slotSetFromList( int i );
+    void slotSetFromList(int i);
     void slotSetFromURL();
     void slotFillList();
-    void slotProcessGoogleResult(KJob*);
+    void slotProcessGoogleResult(KJob *);
 
     /**Make sure download has finished, then make sure file exists, then add image to list */
     void slotJobResult(KJob *);
 
-private:
-    QPixmap shrinkImage( QPixmap *original, int newSize, bool setImage=false );
-    void parseGooglePage(const QString &URL );
+  private:
+    QPixmap shrinkImage(QPixmap *original, int newSize, bool setImage = false);
+    void parseGooglePage(const QString &URL);
 
     int SelectedImageIndex;
-    double wid, ht;
+    double thumbWidth, thumbHeight;
     ThumbnailPickerUI *ui;
     QPixmap *Image;
-    DetailDialog *dd;
     SkyObject *Object;
-    QList<KIO::Job*> JobList;
-    QList<QPixmap*> PixList;
+    QList<KIO::Job *> JobList;
+    QList<QPixmap *> PixList;
     bool bImageFound;
     QRect *ImageRect;
 };
-
-#endif
