@@ -14,21 +14,18 @@
 
 #include <basedevice.h>
 
-
 namespace Ekos
 {
-
 Dome::Dome()
 {
     new DomeAdaptor(this);
-    QDBusConnection::sessionBus().registerObject("/KStars/Ekos/Dome",  this);
+    QDBusConnection::sessionBus().registerObject("/KStars/Ekos/Dome", this);
 
-    currentDome = NULL;
+    currentDome = nullptr;
 }
 
 Dome::~Dome()
 {
-
 }
 
 void Dome::setDome(ISD::GDInterface *newDome)
@@ -38,7 +35,7 @@ void Dome::setDome(ISD::GDInterface *newDome)
 
 bool Dome::canPark()
 {
-    if (currentDome == NULL)
+    if (currentDome == nullptr)
         return false;
 
     return currentDome->canPark();
@@ -46,7 +43,7 @@ bool Dome::canPark()
 
 bool Dome::park()
 {
-    if (currentDome == NULL || currentDome->canPark() == false)
+    if (currentDome == nullptr || currentDome->canPark() == false)
         return false;
 
     return currentDome->Park();
@@ -54,7 +51,7 @@ bool Dome::park()
 
 bool Dome::unpark()
 {
-    if (currentDome == NULL || currentDome->canPark() == false)
+    if (currentDome == nullptr || currentDome->canPark() == false)
         return false;
 
     return currentDome->UnPark();
@@ -62,7 +59,7 @@ bool Dome::unpark()
 
 bool Dome::abort()
 {
-    if (currentDome == NULL)
+    if (currentDome == nullptr)
         return false;
 
     return currentDome->Abort();
@@ -70,7 +67,7 @@ bool Dome::abort()
 
 bool Dome::isMoving()
 {
-    if (currentDome == NULL)
+    if (currentDome == nullptr)
         return false;
 
     return currentDome->isMoving();
@@ -78,12 +75,12 @@ bool Dome::isMoving()
 
 Dome::ParkingStatus Dome::getParkingStatus()
 {
-    if (currentDome == NULL || currentDome->canPark() == false)
+    if (currentDome == nullptr || currentDome->canPark() == false)
         return PARKING_ERROR;
 
     ISwitchVectorProperty *parkSP = currentDome->getBaseDevice()->getSwitch("DOME_PARK");
 
-    if (parkSP == NULL)
+    if (parkSP == nullptr)
         return PARKING_ERROR;
 
     switch (parkSP->s)
@@ -98,7 +95,7 @@ Dome::ParkingStatus Dome::getParkingStatus()
                 return UNPARKING_OK;
             break;
 
-         case IPS_BUSY:
+        case IPS_BUSY:
             if (parkSP->sp[0].s == ISS_ON)
                 return PARKING_BUSY;
             else
@@ -110,9 +107,4 @@ Dome::ParkingStatus Dome::getParkingStatus()
 
     return PARKING_ERROR;
 }
-
-
-
 }
-
-
