@@ -17,7 +17,7 @@
 DSLRInfo::DSLRInfo(QWidget *parent, ISD::CCD *ccd) : QDialog(parent)
 {
 #ifdef Q_OS_OSX
-        setWindowFlags(Qt::Tool| Qt::WindowStaysOnTopHint);
+    setWindowFlags(Qt::Tool | Qt::WindowStaysOnTopHint);
 #endif
 
     setupUi(this);
@@ -26,13 +26,14 @@ DSLRInfo::DSLRInfo(QWidget *parent, ISD::CCD *ccd) : QDialog(parent)
 
     connect(buttonBox, SIGNAL(accepted()), this, SLOT(save()));
 
-    DSLRIcon->setPixmap(QIcon::fromTheme("camera-photo", QIcon(":/icons/breeze/default/camera-photo.svg")).pixmap(48,48));
+    DSLRIcon->setPixmap(
+        QIcon::fromTheme("camera-photo", QIcon(":/icons/breeze/default/camera-photo.svg")).pixmap(48, 48));
 }
 
 void DSLRInfo::save()
 {
-    int w = maxWidth->value();
-    int h = maxHeight->value();
+    int w    = maxWidth->value();
+    int h    = maxHeight->value();
     double x = pixelX->value();
     double y = pixelY->value();
 
@@ -47,4 +48,3 @@ void DSLRInfo::save()
 
     currentCCD->setConfig(SAVE_CONFIG);
 }
-
