@@ -1,14 +1,20 @@
-/*
-    SPDX-FileCopyrightText: 2017 Bob Majewski <cygnus257@yahoo.com>
+/*  Image Guide Algorithm
+    Copyright (C) 2017 Bob Majewski <cygnus257@yahoo.com>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
-*/
+    This application is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+ */
 
 #include "imageautoguiding.h"
 
-#include <qglobal.h>
+#include <QtGlobal>
 
-#include <cmath>
+#include <math.h>
+#include <stddef.h>
+#include <stdio.h>
+#include <stdlib.h>
 
 #define SWAP(a, b) \
     tempr = (a);   \
@@ -287,7 +293,7 @@ void fournNR(float data[], unsigned long nn[], long ndim, long isign)
     long idim;
     unsigned long i1, i2rev, i3rev, ip1, ip2, ip3, ifp1, ifp2;
     unsigned long i2, i3;
-    unsigned long ibit, k1 = 0, k2, n, nprev, nrem, ntot;
+    unsigned long ibit, k1, k2, n, nprev, nrem, ntot;
     float wi, wr, tempi, tempr;
     double theta, wpi, wpr, wtemp;
 
