@@ -8,7 +8,6 @@
     version 2 of the License, or (at your option) any later version.
 */
 
-
 #ifndef FITSView_H_
 #define FITSView_H_
 
@@ -43,38 +42,37 @@
 #include "fitsdata.h"
 
 #define MINIMUM_PIXEL_RANGE 5
-#define MINIMUM_STDVAR  5
+#define MINIMUM_STDVAR      5
 
 class FITSLabel;
 
 class FITSView : public QScrollArea
 {
     Q_OBJECT
-public:    
-
-    FITSView(QWidget *parent = 0, FITSMode mode=FITS_NORMAL, FITSScale filter=FITS_NONE);
+  public:
+    FITSView(QWidget *parent = 0, FITSMode mode = FITS_NORMAL, FITSScale filter = FITS_NONE);
     ~FITSView();
 
     /* Loads FITS image, scales it, and displays it in the GUI */
-    bool  loadFITS(const QString &filename, bool silent=true);
+    bool loadFITS(const QString &filename, bool silent = true);
     /* Save FITS */
     int saveFITS(const QString &filename);
     /* Rescale image lineary from image_buffer, fit to window if desired */
-    int rescale(FITSZoom type);    
+    int rescale(FITSZoom type);
 
     void setImageData(FITSData *d) { imageData = d; }
 
     // Access functions
     FITSData *getImageData() { return imageData; }
     double getCurrentZoom() { return currentZoom; }
-    QImage * getDisplayImage() { return display_image; }    
+    QImage *getDisplayImage() { return display_image; }
 
     // Tracking square
     void setTrackingBoxEnabled(bool enable);
     bool isTrackingBoxEnabled() { return trackingBoxEnabled; }
-    QPixmap & getTrackingBoxPixmap();
-    void setTrackingBox(const QRect & rect);
-    const QRect & getTrackingBox() { return trackingBox; }
+    QPixmap &getTrackingBoxPixmap();
+    void setTrackingBox(const QRect &rect);
+    const QRect &getTrackingBox() { return trackingBox; }
 
     // Overlay
     virtual void drawOverlay(QPainter *);
@@ -82,7 +80,7 @@ public:
     // Overlay objects
     void drawStarCentroid(QPainter *);
     void drawTrackingBox(QPainter *);
-    void drawMarker(QPainter *);    
+    void drawMarker(QPainter *);
     void drawCrosshair(QPainter *);
     void drawEQGrid(QPainter *);
     void drawObjectNames(QPainter *painter);
@@ -92,7 +90,7 @@ public:
     bool areObjectsShown();
     bool isEQGridShown();
     bool isPixelGridShown();
-    bool imageHasWCS();    
+    bool imageHasWCS();
 
     void updateFrame();
 
@@ -104,12 +102,12 @@ public:
     void setMouseMode(int mode);
     void updateMouseCursor();
 
-    static const int dragMouse=0;
-    static const int selectMouse=1;
-    static const int scopeMouse=2;
+    static const int dragMouse   = 0;
+    static const int selectMouse = 1;
+    static const int scopeMouse  = 2;
 
     void updateScopeButton();
-    void setScopeButton(QAction *action){centerTelescopeAction=action;}
+    void setScopeButton(QAction *action) { centerTelescopeAction = action; }
     int lastMouseMode;
 
     // Zoom related
@@ -119,13 +117,13 @@ public:
     // Star Detection
     int findStars(StarAlgorithm algorithm = ALGORITHM_CENTROID);
     void toggleStars(bool enable);
-    void setStarsEnabled(bool enable) { markStars  = enable; }
+    void setStarsEnabled(bool enable);
 
     // FITS Mode
     void updateMode(FITSMode mode);
-    FITSMode getMode() { return mode;}
+    FITSMode getMode() { return mode; }
 
-    void setFilter(FITSScale newFilter) { filter = newFilter;}
+    void setFilter(FITSScale newFilter) { filter = newFilter; }
 
     void setFirstLoad(bool value);
 
@@ -135,16 +133,18 @@ public:
     // Floating toolbar
     void createFloatingToolBar();
 
-protected:
-    void wheelEvent(QWheelEvent* event);
-    void resizeEvent(QResizeEvent * event);
+    //void setLoadWCSEnabled(bool value);
 
-    QFutureWatcher<bool> wcsWatcher;                // WCS Future Watcher
-    QPointF markerCrosshair;                        // Cross hair
-    FITSData *imageData;                            // Pointer to FITSData object
-    double currentZoom;                             // Current zoom level
+  protected:
+    void wheelEvent(QWheelEvent *event);
+    void resizeEvent(QResizeEvent *event);
 
-public slots:
+    QFutureWatcher<bool> wcsWatcher; // WCS Future Watcher
+    QPointF markerCrosshair;         // Cross hair
+    FITSData *imageData;             // Pointer to FITSData object
+    double currentZoom;              // Current zoom level
+
+  public slots:
     void ZoomIn();
     void ZoomOut();
     void ZoomDefault();
@@ -156,24 +156,31 @@ public slots:
     void togglePixelGrid();
     void toggleCrosshair();
 
+    // Stars
+    void toggleStars();
+
     void centerTelescope();
 
     void processPointSelection(int x, int y);
     void processMarkerSelection(int x, int y);
 
-protected slots:
-    void handleWCSCompletion();
+  protected slots:
+    /**
+         * @brief syncWCSState Update toolbar and actions depending on whether WCS is available or not
+         */
+    void syncWCSState();
+    //void handleWCSCompletion();
 
-private:
-    QLabel *noImageLabel=new QLabel();
+  private:
+    QLabel *noImageLabel = new QLabel();
     QPixmap noImage;
 
     bool event(QEvent *event);
     bool gestureEvent(QGestureEvent *event);
     void pinchTriggered(QPinchGesture *gesture);
 
-
-    template<typename T> int rescale(FITSZoom type);
+    template <typename T>
+    int rescale(FITSZoom type);
 
     double average();
     double stddev();
@@ -186,29 +193,29 @@ private:
 
     int image_width, image_height;
 
-    uint16_t currentWidth,currentHeight; /* Current width and height due to zoom */
-    const double zoomFactor;           /* Image zoom factor */    
+    uint16_t currentWidth, currentHeight; /* Current width and height due to zoom */
+    const double zoomFactor;              /* Image zoom factor */
 
-    int data_type;                     /* FITS data type when opened */
-    QImage  *display_image;            /* FITS image that is displayed in the GUI */
+    int data_type;         /* FITS data type when opened */
+    QImage *display_image; /* FITS image that is displayed in the GUI */
     FITSHistogram *histogram;
 
     double maxPixel, minPixel;
 
     bool firstLoad;
-    bool markStars;
-    bool showCrosshair=false;
-    bool showObjects=false;
-    bool showEQGrid=false;
-    bool showPixelGrid=false;
-    bool starsSearched=false;
+    bool markStars     = false;
+    bool showCrosshair = false;
+    bool showObjects   = false;
+    bool showEQGrid    = false;
+    bool showPixelGrid = false;
+    bool starsSearched = false;
 
     QPointF getPointForGridLabel();
     bool pointIsInImage(QPointF pt, bool scaled);
 
-    int mouseMode=1;
-    bool zooming=false;
-    int zoomTime=0;
+    int mouseMode = 1;
+    bool zooming  = false;
+    int zoomTime  = 0;
     QPoint zoomLocation;
 
     QString filename;
@@ -230,17 +237,18 @@ private:
     QPixmap scopePixmap;
 
     // Floating toolbar
-    QToolBar *floatingToolBar = NULL;
-    QAction *centerTelescopeAction = NULL;    
+    QToolBar *floatingToolBar      = nullptr;
+    QAction *centerTelescopeAction = nullptr, *toggleEQGridAction = nullptr, *toggleObjectsAction = nullptr,
+            *toggleStarsAction = nullptr;
 
-signals:
+  signals:
     void newStatus(const QString &msg, FITSBar id);
     void debayerToggled(bool);
     void wcsToggled(bool);
     void actionUpdated(const QString &name, bool enable);
     void trackingStarSelected(int x, int y);
 
-  friend class FITSLabel;
+    friend class FITSLabel;
 };
 
 #endif
