@@ -1,9 +1,9 @@
 /*
-    File: SkipListElement.C
-    Author: Bruno Grossniklaus, 13.11.97
-    Version: 1.0
-    History:
-    13.11.97; Gro; Version 1.0
+  File: SkipListElement.C
+  Author: Bruno Grossniklaus, 13.11.97
+  Version: 1.0
+  History:
+  13.11.97; Gro; Version 1.0
 */
 
 #include <iostream> // cout
@@ -14,7 +14,7 @@
 SkipListElement::SkipListElement(long level, Key key, Value value) : myLevel(level), myKey(key), myValue(value)
 {
     for (int i = 0; i < SKIPLIST_MAXLEVEL; i++)
-        myNext[i] = nullptr;
+        myNext[i] = 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
