@@ -7,7 +7,6 @@
     version 2 of the License, or (at your option) any later version.
  */
 
-
 #ifndef INDICCD_H
 #define INDICCD_H
 
@@ -33,7 +32,6 @@ class StreamWG;
  */
 namespace ISD
 {
-
 class CCD;
 
 /**
@@ -43,12 +41,12 @@ class CCD;
  */
 class CCDChip
 {
-public:
+  public:
     typedef enum { PRIMARY_CCD, GUIDE_CCD } ChipType;
 
     CCDChip(ISD::CCD *ccd, ChipType cType);
 
-    FITSView * getImageView(FITSMode imageType);
+    FITSView *getImageView(FITSMode imageType);
     void setImageView(FITSView *image, FITSMode imageType);
     void setCaptureMode(FITSMode mode) { captureMode = mode; }
     void setCaptureFilter(FITSScale fType) { captureFilter = fType; }
@@ -63,7 +61,7 @@ public:
     bool resetFrame();
     bool capture(double exposure);
     bool setFrameType(CCDFrameType fType);
-    bool setFrameType(const QString & name);
+    bool setFrameType(const QString &name);
     CCDFrameType getFrameType();
     bool setBinning(int bin_x, int bin_y);
     bool setBinning(CCDBinType binType);
@@ -71,7 +69,7 @@ public:
     bool getBinning(int *bin_x, int *bin_y);
     bool getMaxBin(int *max_xbin, int *max_ybin);
     ChipType getType() const { return type; }
-    ISD::CCD *getCCD() { return parentCCD;}
+    ISD::CCD *getCCD() { return parentCCD; }
 
     // Set Image Info
     bool setImageInfo(uint16_t width, uint16_t height, double pixelX, double pixelY, uint8_t bitdepth);
@@ -81,13 +79,13 @@ public:
     bool isCapturing();
     bool abortExposure();
 
-    FITSMode getCaptureMode() const { return captureMode;}
+    FITSMode getCaptureMode() const { return captureMode; }
     FITSScale getCaptureFilter() const { return captureFilter; }
     bool isBatchMode() const { return batchMode; }
     void setBatchMode(bool enable) { batchMode = enable; }
     QStringList getFrameTypes() const { return frameTypes; }
-    void addFrameLabel(const QString & label) { frameTypes << label; }
-    void clearFrameTypes() { frameTypes.clear();}
+    void addFrameLabel(const QString &label) { frameTypes << label; }
+    void clearFrameTypes() { frameTypes.clear(); }
 
     bool canBin() const;
     void setCanBin(bool value);
@@ -106,7 +104,7 @@ public:
 
     QStringList getISOList() const;
 
-private:
+  private:
     QPointer<FITSView> normalImage, focusImage, guideImage, calibrationImage, alignImage;
     FITSData *imageData;
     FITSMode captureMode;
@@ -122,7 +120,6 @@ private:
     bool CanAbort;
     ISD::CCD *parentCCD;
     //int fx,fy,fw,fh;
-
 };
 
 /**
@@ -136,24 +133,29 @@ class CCD : public DeviceDecorator
 {
     Q_OBJECT
 
-public:
-
+  public:
     CCD(GDInterface *iPtr);
     ~CCD();
 
     typedef enum { UPLOAD_CLIENT, UPLOAD_LOCAL, UPLOAD_BOTH } UploadMode;
     typedef enum { FORMAT_FITS, FORMAT_NATIVE } TransferFormat;
-    enum BlobType { BLOB_IMAGE, BLOB_FITS, BLOB_RAW, BLOB_OTHER} BType;
+    enum BlobType
+    {
+        BLOB_IMAGE,
+        BLOB_FITS,
+        BLOB_RAW,
+        BLOB_OTHER
+    } BType;
     typedef enum { TELESCOPE_PRIMARY, TELESCOPE_GUIDE } TelescopeType;
 
     void registerProperty(INDI::Property *prop);
     void processSwitch(ISwitchVectorProperty *svp);
-    void processText(ITextVectorProperty* tvp);
+    void processText(ITextVectorProperty *tvp);
     void processNumber(INumberVectorProperty *nvp);
     void processLight(ILightVectorProperty *lvp);
     void processBLOB(IBLOB *bp);
 
-    DeviceFamily getType() { return dType;}
+    DeviceFamily getType() { return dType; }
     bool hasGuideHead();
     bool hasCooler();
     bool hasCoolerControl();
@@ -166,10 +168,16 @@ public:
     void setISOMode(bool enable) { ISOMode = enable; }
     void setSeqPrefix(const QString &preFix) { seqPrefix = preFix; }
     void setNextSequenceID(int count) { nextSequenceID = count; }
-    void setFilter(const QString & newFilter) { filter = newFilter;}
+    void setFilter(const QString &newFilter) { filter = newFilter; }
+
+    // Gain
+    bool hasGain() { return gainN != nullptr; }
+    bool getGain(double *value);
+    bool getGainMinMaxStep(double *min, double *max, double *step);
+    bool setGain(double value);
 
     // Rapid Guide
-    bool configureRapidGuide(CCDChip *targetChip, bool autoLoop, bool sendImage=false, bool showMarker=false);
+    bool configureRapidGuide(CCDChip *targetChip, bool autoLoop, bool sendImage = false, bool showMarker = false);
     bool setRapidGuide(CCDChip *targetChip, bool enable);
 
     // Upload Settings
@@ -181,6 +189,10 @@ public:
     TransferFormat getTransferFormat() { return transferFormat; }
     bool setTransformFormat(CCD::TransferFormat format);
 
+    // BLOB control
+    bool isBLOBEnabled();
+    bool setBLOBEnabled(bool enable);
+
     // Video Stream
     bool setVideoStreamEnabled(bool enable);
     bool resetStreamingFrame();
@@ -199,18 +211,21 @@ public:
     TelescopeType getTelescopeType() { return telescopeType; }
     bool setTelescopeType(TelescopeType type);
 
-    FITSViewer *getViewer() { return fv;}
-    CCDChip * getChip(CCDChip::ChipType cType);
-    void setFITSDir(const QString &dir) { fitsDir = dir;}
+    // Update FITS Header
+    bool setFITSHeader(const QMap<QString, QString> &values);
+
+    FITSViewer *getViewer() { return fv; }
+    CCDChip *getChip(CCDChip::ChipType cType);
+    void setFITSDir(const QString &dir) { fitsDir = dir; }
 
     TransferFormat getTargetTransferFormat() const;
     void setTargetTransferFormat(const TransferFormat &value);
 
-public slots:
+  public slots:
     void FITSViewerDestroyed();
     void StreamWindowHidden();
 
-signals:
+  signals:
     //void FITSViewerClosed();
     void newTemperatureValue(double value);
     void newExposureValue(ISD::CCDChip *chip, double value, IPState state);
@@ -221,7 +236,7 @@ signals:
     void videoRecordToggled(bool enabled);
     void newFPS(double instantFPS, double averageFPS);
 
-private:
+  private:
     void addFITSKeywords(QString filename);
     QString filter;
 
@@ -230,8 +245,8 @@ private:
     bool HasCooler;
     bool HasCoolerControl;
     bool HasVideoStream;
-    QString		seqPrefix;
-    QString     fitsDir;
+    QString seqPrefix;
+    QString fitsDir;
     char BLOBFilename[MAXINDIFILENAME];
     int nextSequenceID;
     StreamWG *streamWindow;
@@ -242,11 +257,11 @@ private:
     TransferFormat transferFormat, targetTransferFormat;
     TelescopeType telescopeType = TELESCOPE_PRIMARY;
 
+    // Gain, since it is spread among different vector properties, let's try to find the property itself.
+    INumber *gainN = nullptr;
+
     QPointer<FITSViewer> fv;
     QPointer<ImageViewer> imageViewer;
-
-
 };
-
 }
 #endif // INDICCD_H
