@@ -22,35 +22,36 @@ class KSComet;
 class SkyObject;
 class SatellitesComponent;
 
-    /**
-     * @class SatellitesItem
-     * This class handles representation of satellites in SkyMapLite
-     *
-     * @author Artem Fedoskin
-     * @version 1.0
-     */
+/**
+ * @class SatellitesItem
+ * This class handles representation of satellites in SkyMapLite
+ *
+ * @author Artem Fedoskin
+ * @version 1.0
+ */
 
-class SatellitesItem : public SkyItem {
-public:
+class SatellitesItem : public SkyItem
+{
+  public:
     /**
-     * @short Constructor
-     * @param satComp - pointer to SatellitesComponent that handles data
-     * @param rootNode parent RootNode that instantiates this object
-     */
+         * @short Constructor
+         * @param satComp - pointer to SatellitesComponent that handles data
+         * @param rootNode parent RootNode that instantiates this object
+         */
     SatellitesItem(SatellitesComponent *satComp, RootNode *rootNode = 0);
 
     /**
-     * @short recreates the node tree (deletes old nodes and appends new ones according to
-     * SatelliteGroups from SatellitesComponent::groups())
-     */
+         * @short recreates the node tree (deletes old nodes and appends new ones according to
+         * SatelliteGroups from SatellitesComponent::groups())
+         */
     void recreateList();
 
     /**
-     * @short Update positions and visibility of satellites
-     */
+         * @short Update positions and visibility of satellites
+         */
     virtual void update() override;
 
-private:
+  private:
     SatellitesComponent *m_satComp;
 };
 #endif
