@@ -23,27 +23,29 @@
 #include "skymaplite.h"
 #include "Options.h"
 
-PointNode::PointNode(RootNode* p, char sp, float size)
-    :spType(sp), texture(new QSGSimpleTextureNode), m_rootNode(p), m_size(-1), //Important to init to -1
+PointNode::PointNode(RootNode *p, char sp, float size)
+    : spType(sp), texture(new QSGSimpleTextureNode), m_rootNode(p), m_size(-1), //Important to init to -1
       starColorMode(Options::starColorMode())
 {
     appendChildNode(texture);
     setSize(size);
 }
 
-void PointNode::setSize(float size) {
-    int isize = qMin(static_cast<int>(size), 14);
+void PointNode::setSize(float size)
+{
+    int isize      = qMin(static_cast<int>(size), 14);
     uint newStarCM = Options::starColorMode();
-    if(size != m_size || newStarCM != starColorMode) {
+    if (size != m_size || newStarCM != starColorMode)
+    {
         texture->setTexture(m_rootNode->getCachedTexture(isize, spType));
 
         //We divide size of texture by ratio. Otherwise texture will be very large
         qreal ratio = SkyMapLite::Instance()->window()->effectiveDevicePixelRatio();
 
-        QSize tSize = texture->texture()->textureSize();
+        QSize tSize    = texture->texture()->textureSize();
         QRectF oldRect = texture->rect();
-        texture->setRect(QRect(oldRect.x(),oldRect.y(),tSize.width()/ratio,tSize.height()/ratio));
-        m_size = size;
+        texture->setRect(QRect(oldRect.x(), oldRect.y(), tSize.width() / ratio, tSize.height() / ratio));
+        m_size        = size;
         starColorMode = newStarCM;
     }
 }
