@@ -26,13 +26,14 @@ class SkyNode;
  * @short Convenience class that represents trixel in SkyMapLite. It should be used as a parent for
  * nodes that represent SkyObjects indexed by HTMesh
  */
-class TrixelNode : public SkyOpacityNode {
-public:
+class TrixelNode : public SkyOpacityNode
+{
+  public:
     /** Constructor. **/
     TrixelNode(Trixel trixel);
 
     /** m_hideCount is a counter of how much updates of SkyMapLite this trixel remained
-        hidden. Used to reduce memory consumption**/
+            hidden. Used to reduce memory consumption**/
     inline int hideCount() { return m_hideCount; }
 
     /** Whenever the corresponding trixel is visible, m_hideCount is reset */
@@ -44,17 +45,16 @@ public:
     inline Trixel trixelID() { return m_trixel; }
 
     /**
-     * @short m_nodes - holds SkyNodes with corresponding SkyObjects
-     */
+         * @short m_nodes - holds SkyNodes with corresponding SkyObjects
+         */
     QLinkedList<QPair<SkyObject *, SkyNode *>> m_nodes;
 
     /** @short Delete all childNodes and remove nodes from pairs in m_nodes **/
     virtual void deleteAllChildNodes();
 
-private:
+  private:
     Trixel m_trixel;
     int m_hideCount;
 };
 
-
 #endif
