@@ -23,7 +23,6 @@
 
 class KStars;
 
-
 /** @class OpsSupernovae
  *The Supernovae Tab of the Options window.  In this Tab the user can configure
  *supernovae options and select if supernovae should be drawn on the skymap.
@@ -36,24 +35,16 @@ class OpsSupernovae : public QFrame, public Ui::OpsSupernovae
 {
     Q_OBJECT
 
-public:
+  public:
     /**
-     * Constructor
-     */
+         * Constructor
+         */
     explicit OpsSupernovae();
 
     /**
-     * Destructor
-     */
-    ~OpsSupernovae();
-
-private slots:
-    void slotUpdateRecentSupernovae();
-    void slotShowSupernovae( bool on );
-    void slotUpdateOnStartup( bool on );
-    void slotShowSupernovaAlerts( bool on );
-    void slotSetShowMagnitudeLimit( double value );
-    void slotSetAlertMagnitudeLimit( double value );
+         * Destructor
+         */
+    ~OpsSupernovae() {}
 };
 
-#endif  //OPSSUPERNOVAE_H_
+#endif //OPSSUPERNOVAE_H_
