@@ -28,38 +28,39 @@
 	*@version 1.0
 	*/
 
-class KSSun : public KSPlanet  {
-public:
+class KSSun : public KSPlanet
+{
+  public:
     /** Constructor.  Defines constants needed by findPosition().
-    	*Sets Ecliptic coordinates appropriate for J2000.
-    	*@param kd pointer to KStarsData object
-    	*/
+        	*Sets Ecliptic coordinates appropriate for J2000.
+        	*@param kd pointer to KStarsData object
+        	*/
     KSSun();
 
-    virtual KSSun* clone() const;
-    virtual SkyObject::UID getUID() const;
+    KSSun *clone() const Q_DECL_OVERRIDE;
+    SkyObject::UID getUID() const Q_DECL_OVERRIDE;
 
     /** Destructor (empty)
-    	*/
+        	*/
     virtual ~KSSun() {}
 
     /** Read orbital data from disk
-    	*@note reimplemented from KSPlanet
-    	*@note we actually read Earth's orbital data.  The Sun's geocentric
-    	*ecliptic coordinates are by definition exactly the opposite of the 
-    	*Earth's heliocentric ecliptic coordinates.
-    	*/
-    virtual bool loadData();
+        	*@note reimplemented from KSPlanet
+        	*@note we actually read Earth's orbital data.  The Sun's geocentric
+        	*ecliptic coordinates are by definition exactly the opposite of the
+        	*Earth's heliocentric ecliptic coordinates.
+        	*/
+    bool loadData() Q_DECL_OVERRIDE;
 
-
-protected:
+  protected:
     /** Determine geocentric RA, Dec coordinates for the Epoch given in the argument.
-    	*@p Epoch current Julian Date
-    	*@p Earth pointer to earth object
-    	*/
-    virtual bool findGeocentricPosition( const KSNumbers *num, const KSPlanetBase *Earth=NULL );
-private:
-    virtual void findMagnitude(const KSNumbers*);
+        	*@p Epoch current Julian Date
+        	*@p Earth pointer to earth object
+        	*/
+    bool findGeocentricPosition(const KSNumbers *num, const KSPlanetBase *Earth = nullptr) Q_DECL_OVERRIDE;
+
+  private:
+    void findMagnitude(const KSNumbers *) Q_DECL_OVERRIDE;
 };
 long double equinox(int year, int d, int m, int angle);
 
