@@ -30,28 +30,27 @@ class QTextStream;
   *@author Jasem Mutlaq
   *@version 1.0
   */
-class modCalcAngDist : public QFrame, public Ui::modCalcAngDistDlg  {
-
+class modCalcAngDist : public QFrame, public Ui::modCalcAngDistDlg
+{
     Q_OBJECT
-public:
+  public:
     /**Constructor. */
     explicit modCalcAngDist(QWidget *p);
     /**Destructor. */
     ~modCalcAngDist();
 
-public slots:
+  public slots:
     void slotValidatePositions();
     void slotObjectButton();
     void slotResetTitle();
     void slotRunBatch();
 
-private:
+  private:
     /** Process Lines **/
-    void processLines( QTextStream &istream );
+    void processLines(QTextStream &istream);
 
     /** @returns a SkyPoint constructed from the coordinates in the RA and Dec dmsBoxes. */
-    SkyPoint getCoords(dmsBox * rBox, dmsBox* dBox, bool *ok);
-
+    SkyPoint getCoords(dmsBox *rBox, dmsBox *dBox, bool *ok);
 };
 
 #endif
