@@ -33,50 +33,55 @@ class QUrl;
 class KStars;
 class ScriptFunction;
 
-class OptionsTreeViewWidget : public QFrame, public Ui::OptionsTreeView {
+class OptionsTreeViewWidget : public QFrame, public Ui::OptionsTreeView
+{
     Q_OBJECT
-public:
-    explicit OptionsTreeViewWidget( QWidget *p );
+  public:
+    explicit OptionsTreeViewWidget(QWidget *p);
 };
 
-class OptionsTreeView : public QDialog {
+class OptionsTreeView : public QDialog
+{
     Q_OBJECT
-public:
-    explicit OptionsTreeView( QWidget *p );
+  public:
+    explicit OptionsTreeView(QWidget *p);
     ~OptionsTreeView();
-    QTreeWidget* optionsList() { return otvw->OptionsList; }
+    QTreeWidget *optionsList() { return otvw->OptionsList; }
     void resizeColumns();
 
-private:
+  private:
     OptionsTreeViewWidget *otvw;
 };
 
-class ScriptNameWidget : public QFrame, public Ui::ScriptNameDialog {
+class ScriptNameWidget : public QFrame, public Ui::ScriptNameDialog
+{
     Q_OBJECT
-public:
-    explicit ScriptNameWidget( QWidget *p );
+  public:
+    explicit ScriptNameWidget(QWidget *p);
 };
 
-class ScriptNameDialog : public QDialog {
+class ScriptNameDialog : public QDialog
+{
     Q_OBJECT
-public:
-    explicit ScriptNameDialog( QWidget *p );
+  public:
+    explicit ScriptNameDialog(QWidget *p);
     ~ScriptNameDialog();
     QString scriptName() const { return snw->ScriptName->text(); }
     QString authorName() const { return snw->AuthorName->text(); }
 
-private slots:
+  private slots:
     void slotEnableOkButton();
 
-private:
+  private:
     ScriptNameWidget *snw;
     QPushButton *okB;
 };
 
-class ScriptBuilderUI : public QFrame, public Ui::ScriptBuilder {
+class ScriptBuilderUI : public QFrame, public Ui::ScriptBuilder
+{
     Q_OBJECT
-public:
-    explicit ScriptBuilderUI( QWidget *p );
+  public:
+    explicit ScriptBuilderUI(QWidget *p);
 };
 
 /** @class ScriptBuilder
@@ -84,20 +89,21 @@ public:
 	*@author Jason Harris
 	*@version 1.0
 	*/
-class ScriptBuilder : public QDialog {
+class ScriptBuilder : public QDialog
+{
     Q_OBJECT
-public:
-    explicit ScriptBuilder( QWidget *parent );
+  public:
+    explicit ScriptBuilder(QWidget *parent);
     ~ScriptBuilder();
 
     bool unsavedChanges() const { return UnsavedChanges; }
-    void setUnsavedChanges( bool b=true );
+    void setUnsavedChanges(bool b = true);
     void saveWarning();
-    void readScript( QTextStream &istream );
-    void writeScript( QTextStream &ostream );
-    bool parseFunction( QString fn_name, QStringList &fn );
+    void readScript(QTextStream &istream);
+    void writeScript(QTextStream &ostream);
+    bool parseFunction(QString fn_name, QStringList &fn);
 
-public slots:
+  public slots:
     void slotAddFunction();
     void slotMoveFunctionUp();
     void slotMoveFunctionDown();
@@ -140,48 +146,48 @@ public slots:
     void slotChangeColorName();
     void slotLoadColorScheme();
 
-	#if 0
-    void slotINDIWaitCheck(bool toggleState);
-    void slotINDIFindObject();
-    void slotINDIStartDeviceName();
-    void slotINDIStartDeviceMode();
-    void slotINDISetDevice();
-    void slotINDIShutdown();
-    void slotINDISwitchDeviceConnection();
-    void slotINDISetPortDevicePort();
-    void slotINDISetTargetCoordDeviceRA();
-    void slotINDISetTargetCoordDeviceDEC();
-    void slotINDISetTargetNameTargetName();
-    void slotINDISetActionName();
-    void slotINDIWaitForActionName();
-    void slotINDISetFocusSpeed();
-    void slotINDIStartFocusDirection();
-    void slotINDISetFocusTimeout();
-    void slotINDISetGeoLocationDeviceLong();
-    void slotINDISetGeoLocationDeviceLat();
-    void slotINDIStartExposureTimeout();
-    void slotINDISetUTC();
-    void slotINDISetScopeAction();
-    void slotINDISetFrameType();
-    void slotINDISetCCDTemp();
-    void slotINDISetFilterNum();
-	#endif
+#if 0
+        void slotINDIWaitCheck(bool toggleState);
+        void slotINDIFindObject();
+        void slotINDIStartDeviceName();
+        void slotINDIStartDeviceMode();
+        void slotINDISetDevice();
+        void slotINDIShutdown();
+        void slotINDISwitchDeviceConnection();
+        void slotINDISetPortDevicePort();
+        void slotINDISetTargetCoordDeviceRA();
+        void slotINDISetTargetCoordDeviceDEC();
+        void slotINDISetTargetNameTargetName();
+        void slotINDISetActionName();
+        void slotINDIWaitForActionName();
+        void slotINDISetFocusSpeed();
+        void slotINDIStartFocusDirection();
+        void slotINDISetFocusTimeout();
+        void slotINDISetGeoLocationDeviceLong();
+        void slotINDISetGeoLocationDeviceLat();
+        void slotINDIStartExposureTimeout();
+        void slotINDISetUTC();
+        void slotINDISetScopeAction();
+        void slotINDISetFrameType();
+        void slotINDISetCCDTemp();
+        void slotINDISetFilterNum();
+#endif
 
-private:
+  private:
     void initViewOptions();
-    void warningMismatch (const QString &expected) const;
+    void warningMismatch(const QString &expected) const;
 
     ScriptBuilderUI *sb;
 
     KStars *ks; //parent needed for sub-dialogs
-    QList<ScriptFunction*> KStarsFunctionList;
-    QList<ScriptFunction*> SimClockFunctionList;
+    QList<ScriptFunction *> KStarsFunctionList;
+    QList<ScriptFunction *> SimClockFunctionList;
 
-	#if 0
-    QList<ScriptFunction*> INDIFunctionList;
-	#endif
+#if 0
+        QList<ScriptFunction *> INDIFunctionList;
+#endif
 
-    QList<ScriptFunction*> ScriptList;
+    QList<ScriptFunction *> ScriptList;
 
     QWidget *argBlank;
     ArgLookToward *argLookToward;
@@ -201,27 +207,27 @@ private:
     ArgSetColor *argSetColor;
     ArgLoadColorScheme *argLoadColorScheme;
 
-	#if 0
-    ArgStartINDI *argStartINDI;
-    ArgSetDeviceINDI *argSetDeviceINDI;
-    ArgShutdownINDI *argShutdownINDI;
-    ArgSwitchINDI *argSwitchINDI;
-    ArgSetPortINDI *argSetPortINDI;
-    ArgSetTargetCoordINDI *argSetTargetCoordINDI;
-    ArgSetTargetNameINDI *argSetTargetNameINDI;
-    ArgSetActionINDI *argSetActionINDI;
-    ArgSetActionINDI *argWaitForActionINDI;
-    ArgSetFocusSpeedINDI *argSetFocusSpeedINDI;
-    ArgStartFocusINDI *argStartFocusINDI;
-    ArgSetFocusTimeoutINDI *argSetFocusTimeoutINDI;
-    ArgSetGeoLocationINDI *argSetGeoLocationINDI;
-    ArgStartExposureINDI *argStartExposureINDI;
-    ArgSetUTCINDI *argSetUTCINDI;
-    ArgSetScopeActionINDI *argSetScopeActionINDI;
-    ArgSetFrameTypeINDI *argSetFrameTypeINDI;
-    ArgSetCCDTempINDI *argSetCCDTempINDI;
-    ArgSetFilterNumINDI *argSetFilterNumINDI;
-	#endif
+#if 0
+        ArgStartINDI * argStartINDI;
+        ArgSetDeviceINDI * argSetDeviceINDI;
+        ArgShutdownINDI * argShutdownINDI;
+        ArgSwitchINDI * argSwitchINDI;
+        ArgSetPortINDI * argSetPortINDI;
+        ArgSetTargetCoordINDI * argSetTargetCoordINDI;
+        ArgSetTargetNameINDI * argSetTargetNameINDI;
+        ArgSetActionINDI * argSetActionINDI;
+        ArgSetActionINDI * argWaitForActionINDI;
+        ArgSetFocusSpeedINDI * argSetFocusSpeedINDI;
+        ArgStartFocusINDI * argStartFocusINDI;
+        ArgSetFocusTimeoutINDI * argSetFocusTimeoutINDI;
+        ArgSetGeoLocationINDI * argSetGeoLocationINDI;
+        ArgStartExposureINDI * argStartExposureINDI;
+        ArgSetUTCINDI * argSetUTCINDI;
+        ArgSetScopeActionINDI * argSetScopeActionINDI;
+        ArgSetFrameTypeINDI * argSetFrameTypeINDI;
+        ArgSetCCDTempINDI * argSetCCDTempINDI;
+        ArgSetFilterNumINDI * argSetFilterNumINDI;
+#endif
 
     ScriptNameDialog *snd;
     OptionsTreeView *otv;
