@@ -27,36 +27,37 @@
 class QDragEnterEvent;
 
 /** @class DragListBox
-	*@short Extension of KListWidget that allows Drag-and-Drop 
+	*@short Extension of KListWidget that allows Drag-and-Drop
 	*with other DragListBoxes
 	*@author Jason Harris
 	*@version 1.0
 	*/
 
-class DragListBox : public QListWidget {
+class DragListBox : public QListWidget
+{
     Q_OBJECT
-public:
+  public:
     /** @short Default constructor
-     */
-    explicit DragListBox( QWidget *parent = 0, const char* name = 0 );
+         */
+    explicit DragListBox(QWidget *parent = 0, const char *name = 0);
 
     /** @short Default destructor
-     */
+         */
     ~DragListBox();
 
     int ignoreIndex() const { return IgnoreIndex; }
-    bool contains( const QString &s ) const;
+    bool contains(const QString &s) const;
 
-    void dragEnterEvent( QDragEnterEvent *evt );
-    void dragMoveEvent( QDragMoveEvent *evt );
-    void dropEvent( QDropEvent *evt );
-    void mousePressEvent( QMouseEvent *evt );
-    void mouseMoveEvent( QMouseEvent * );
-    void mouseReleaseEvent( QMouseEvent * );
-private:
+    void dragEnterEvent(QDragEnterEvent *evt) Q_DECL_OVERRIDE;
+    void dragMoveEvent(QDragMoveEvent *evt) Q_DECL_OVERRIDE;
+    void dropEvent(QDropEvent *evt) Q_DECL_OVERRIDE;
+    void mousePressEvent(QMouseEvent *evt) Q_DECL_OVERRIDE;
+    void mouseMoveEvent(QMouseEvent *) Q_DECL_OVERRIDE;
+    void mouseReleaseEvent(QMouseEvent *) Q_DECL_OVERRIDE;
+
+  private:
     bool leftButtonDown;
     int IgnoreIndex;
-
 };
 
 #endif //DRAGLISTBOX_H
