@@ -22,19 +22,20 @@
 
 class FOV;
 
-class FOVWidget : public QFrame {
+class FOVWidget : public QFrame
+{
     Q_OBJECT
-    public:
-        explicit FOVWidget( QWidget *parent=0 );
-        ~FOVWidget();
+  public:
+    explicit FOVWidget(QWidget *parent = 0);
+    ~FOVWidget();
 
-        void setFOV( FOV *f );
+    void setFOV(FOV *f);
 
-    protected:
-        void paintEvent( QPaintEvent *e );
+  protected:
+    void paintEvent(QPaintEvent *e) Q_DECL_OVERRIDE;
 
-    private:
-        FOV *m_FOV;
+  private:
+    FOV *m_FOV;
 };
 
 #endif
